@@ -1,12 +1,22 @@
 from gersemi.ast_helpers import is_comment
 from gersemi.base_dumper import BaseDumper
+from gersemi.configuration import SortOrder
 from gersemi.utils import pop_all
 
 
 class KeywordPreprocessor(BaseDumper):
+    def _get_node_value(self, node):
+        visited_node = self.visit(node)
+        if self.sort_order == SortOrder.CaseInsensitive:
+            return visited_node.casefold()
+
+        return visited_node
+
     def _get_bucket_value(self, bucket):
         *comments, node = bucket
-        return self.visit(node), tuple(self.visit(comment) for comment in comments)
+        return self._get_node_value(node), tuple(
+            self._get_node_value(comment) for comment in comments
+        )
 
     def _bucket_arguments_with_their_preceding_comments(self, args):
         result = []
